==> jc-1.4.0.tar.gz: soot/coffi/Utf8__5fEnumeration.h <==
// public class soot.coffi.Utf8_Enumeration

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 34fc61703811ad01 soot_coffi_Utf8__5fEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_Utf8__5fEnumeration_H_
#define _JC_soot_coffi_Utf8__5fEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$sub_refs	_jc_soot_coffi_Utf8__5fEnumeration$sub_refs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs	_jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$refs	_jc_soot_coffi_Utf8__5fEnumeration$refs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$nonrefs	_jc_soot_coffi_Utf8__5fEnumeration$nonrefs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$object	_jc_soot_coffi_Utf8__5fEnumeration$object;

typedef const struct _jc_soot_coffi_Utf8__5fEnumeration$vmethods	_jc_soot_coffi_Utf8__5fEnumeration$vmethods;
typedef const struct _jc_soot_coffi_Utf8__5fEnumeration$vtable	_jc_soot_coffi_Utf8__5fEnumeration$vtable;
typedef const struct _jc_soot_coffi_Utf8__5fEnumeration$vtype	_jc_soot_coffi_Utf8__5fEnumeration$vtype;

// Constructors
extern void _jc_soot_coffi_Utf8__5fEnumeration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *);
extern void _jc_soot_coffi_Utf8__5fEnumeration$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *, struct _jc_byte_array *);

// Virtual methods
extern jboolean _jc_soot_coffi_Utf8__5fEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_coffi_Utf8__5fEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *);
extern void _jc_soot_coffi_Utf8__5fEnumeration$method$reset$708e68a9fd4c4473(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *, struct _jc_byte_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Utf8__5fEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_soot_coffi_Utf8__5fEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_soot_coffi_Utf8__5fEnumeration$method_info$reset$708e68a9fd4c4473;

// Virtual methods structure
struct _jc_soot_coffi_Utf8__5fEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *);
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *);
	void	(*reset$708e68a9fd4c4473)(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *, struct _jc_byte_array *);
};

// Vtable
struct _jc_soot_coffi_Utf8__5fEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Utf8__5fEnumeration$vmethods	soot_coffi_Utf8__5fEnumeration;
};

// Vtype
struct _jc_soot_coffi_Utf8__5fEnumeration$vtype {
	_jc_type			type;
	_jc_soot_coffi_Utf8__5fEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Utf8__5fEnumeration$sub_refs {
	_jc_byte_array	*bytes;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Utf8__5fEnumeration$refs {
    _jc_soot_coffi_Utf8__5fEnumeration$sub_refs	soot_coffi_Utf8__5fEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs {
	jint	c;
	jshort	curindex;
	jshort	length;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Utf8__5fEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs	soot_coffi_Utf8__5fEnumeration;
};

// Object instance structure
struct _jc_soot_coffi_Utf8__5fEnumeration$object {
	_jc_soot_coffi_Utf8__5fEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Utf8__5fEnumeration$vtype	*vtype;
	_jc_soot_coffi_Utf8__5fEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Utf8__5fEnumeration$vtype _jc_soot_coffi_Utf8__5fEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Utf8__5fEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Utf8__5fEnumeration$class_object;

#endif	/* _JC_soot_coffi_Utf8__5fEnumeration_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Utf8__5fEnumeration.h <==
// public class soot.coffi.Utf8_Enumeration

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 34fc61703811ad01 soot_coffi_Utf8__5fEnumeration

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_Utf8__5fEnumeration_H_
#define _JC_soot_coffi_Utf8__5fEnumeration_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$sub_refs	_jc_soot_coffi_Utf8__5fEnumeration$sub_refs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs	_jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$refs	_jc_soot_coffi_Utf8__5fEnumeration$refs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$nonrefs	_jc_soot_coffi_Utf8__5fEnumeration$nonrefs;
typedef struct _jc_soot_coffi_Utf8__5fEnumeration$object	_jc_soot_coffi_Utf8__5fEnumeration$object;

typedef const struct _jc_soot_coffi_Utf8__5fEnumeration$vmethods	_jc_soot_coffi_Utf8__5fEnumeration$vmethods;
typedef const struct _jc_soot_coffi_Utf8__5fEnumeration$vtable	_jc_soot_coffi_Utf8__5fEnumeration$vtable;
typedef const struct _jc_soot_coffi_Utf8__5fEnumeration$vtype	_jc_soot_coffi_Utf8__5fEnumeration$vtype;

// Constructors
extern void _jc_soot_coffi_Utf8__5fEnumeration$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Utf8__5fEnumeration$method$_init$aaa7e255fe505158(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_coffi_Utf8__5fEnumeration$method$hasMoreElements$95fbe58f36adadb0(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_coffi_Utf8__5fEnumeration$method$nextElement$9b7c3789fa3ba818(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *) _JC_JCNI_ATTR;
extern void _jc_soot_coffi_Utf8__5fEnumeration$method$reset$708e68a9fd4c4473(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_Utf8__5fEnumeration$method_info$hasMoreElements$95fbe58f36adadb0;
extern _jc_method _jc_soot_coffi_Utf8__5fEnumeration$method_info$nextElement$9b7c3789fa3ba818;
extern _jc_method _jc_soot_coffi_Utf8__5fEnumeration$method_info$reset$708e68a9fd4c4473;

// Virtual methods structure
struct _jc_soot_coffi_Utf8__5fEnumeration$vmethods {
	jboolean	(*hasMoreElements$95fbe58f36adadb0)(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*nextElement$9b7c3789fa3ba818)(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *) _JC_JCNI_ATTR;
	void	(*reset$708e68a9fd4c4473)(_jc_env *, struct _jc_soot_coffi_Utf8__5fEnumeration$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_Utf8__5fEnumeration$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Utf8__5fEnumeration$vmethods	soot_coffi_Utf8__5fEnumeration;
};

// Vtype
struct _jc_soot_coffi_Utf8__5fEnumeration$vtype {
	_jc_type			type;
	_jc_soot_coffi_Utf8__5fEnumeration$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Utf8__5fEnumeration$sub_refs {
	_jc_byte_array	*bytes;
};

// Reference instance fields (object)
struct _jc_soot_coffi_Utf8__5fEnumeration$refs {
    _jc_soot_coffi_Utf8__5fEnumeration$sub_refs	soot_coffi_Utf8__5fEnumeration;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs {
	jint	c;
	jshort	curindex;
	jshort	length;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Utf8__5fEnumeration$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Utf8__5fEnumeration$sub_nonrefs	soot_coffi_Utf8__5fEnumeration;
};

// Object instance structure
struct _jc_soot_coffi_Utf8__5fEnumeration$object {
	_jc_soot_coffi_Utf8__5fEnumeration$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Utf8__5fEnumeration$vtype	*vtype;
	_jc_soot_coffi_Utf8__5fEnumeration$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Utf8__5fEnumeration$vtype _jc_soot_coffi_Utf8__5fEnumeration$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Utf8__5fEnumeration, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Utf8__5fEnumeration$class_object;

#endif	/* _JC_soot_coffi_Utf8__5fEnumeration_H_ */
